#################
Exceptions Module
#################

.. currentmodule:: ovh.exceptions

.. automodule:: ovh.exceptions

.. autoexception:: APIError
.. autoexception:: HTTPError
.. autoexception:: InvalidKey
.. autoexception:: InvalidResponse
.. autoexception:: InvalidRegion
.. autoexception:: ReadOnlyError
.. autoexception:: ResourceNotFoundError
.. autoexception:: BadParametersError
.. autoexception:: ResourceConflictError
.. autoexception:: NetworkError
.. autoexception:: NotGrantedCall
.. autoexception:: NotCredential
.. autoexception:: Forbidden
.. autoexception:: InvalidCredential
